.. _spkg_uri_template:

uri_template: RFC 6570 URI Template Processor
=======================================================

Description
-----------

RFC 6570 URI Template Processor

License
-------

MIT License

Upstream Contact
----------------

https://pypi.org/project/uri-template/


Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    1.3.0

version_requirements.txt::

    uri-template


Equivalent System Packages
--------------------------

(none known)

